ShspInput class
Constructors
- ShspInput({required RawDatagramSocket socket, PeerInfo? peerInfo, String? remoteIp, int? remotePort, String signal = ''})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- peerInfo → PeerInfo?
-
final
- remoteIp → String?
-
final
- remotePort → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signal → String
-
final
- socket → RawDatagramSocket
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited