ShspInstanceInput class

Constructors

ShspInstanceInput({required PeerInfo remotePeer, IShspSocket? socket, RawDatagramSocket? rawSocket, int keepAliveSeconds = 30})

Properties

hashCode int
The hash code for this object.
no setterinherited
keepAliveSeconds int
final
rawSocket RawDatagramSocket?
final
remotePeer → PeerInfo
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
socket → IShspSocket?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited