ShspPeerFactory class

Constructors

ShspPeerFactory()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create({required PeerInfo remotePeer, required IShspSocket socket}) ShspPeer
createFromConfig(ShspPeerInput config) ShspPeer
Create a ShspPeer from a ShspPeerConfig object. If config.socket is provided it will be used; otherwise config.rawSocket will be used to build a socket.
createFromRemoteInfo({required PeerInfo remotePeer, required RawDatagramSocket rawSocket}) ShspPeer
Create a ShspPeer from a RemoteInfo object and a raw socket. This will build required dependencies (MessageCallbackMap and ShspSocket) internally.