ShspSocketFactory class

Constructors

ShspSocketFactory()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create(RawDatagramSocket socket, MessageCallbackMap messageCallbacks) ShspSocket
createFromConfig(ShspSocketInput config) ShspSocket
Create using a configuration object.
createFromSocket(RawDatagramSocket socket) ShspSocket
Create a ShspSocket providing only a RawDatagramSocket. This will create a default MessageCallbackMap internally.