GZipCodec class

GZip compression codec implementation

Fast and reliable compression with excellent compression ratio. Recommended for bandwidth-constrained scenarios and general use.

Uses Dart's built-in dart:io gzip implementation.

  • Speed: ⚡⚡ (moderate)
  • Compression: 50-95% (excellent)
  • CPU: Moderate

Constructors

GZipCodec()

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Human-readable name of the compression algorithm
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(List<int> data) List<int>
Decompress data
encode(List<int> data) List<int>
Compress data
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited