ZstdCodec class

Zstandard (ZSTD) compression codec implementation

Balanced compression algorithm with better compression than LZ4. This uses gzip which provides similar functionality to ZSTD.

Constructors

ZstdCodec()

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Human-readable name of the compression algorithm
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(List<int> data) List<int>
Decompress data
encode(List<int> data) List<int>
Compress data
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited