onError property
Get the callback invoked when the socket encounters an error
Implementation
@override
CallbackOnError get onError => _onError;
Get the callback invoked when the socket encounters an error
@override
CallbackOnError get onError => _onError;