setErrorCallback method
Registers the callback invoked when the socket encounters an error
Implementation
@override
void setErrorCallback(void Function(dynamic err) cb) {
_onError.register(cb);
}
Registers the callback invoked when the socket encounters an error
@override
void setErrorCallback(void Function(dynamic err) cb) {
_onError.register(cb);
}