ShspHandshakeHandler class

Automatic handshake and connection open/close handling

Constructors

ShspHandshakeHandler()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

handshakeInstance(IShspInstance instance, ShspHandshakeHandlerOptions options, [void onOpen(IShspInstance instance)?]) Future<IShspInstance>
Perform handshake procedure and return when connection is open