ShspHandshakeHandlerOptions class

Constructors

ShspHandshakeHandlerOptions({int timeoutMs = 5000, int intervalOfSendingHandshakeMs = 500})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
intervalOfSendingHandshakeMs int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeoutMs int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited