ShspInstanceHandlerSingleton class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(PeerInfo remotePeer)
→ void
-
inherited
-
closeAll()
→ void
-
inherited
-
getShsp(PeerInfo remotePeer)
→ Future<IShspInstance?>
-
inherited
-
getShspSafe(PeerInfo remotePeer)
→ Future<IShspInstance>
-
inherited
-
initiateShsp(PeerInfo remotePeer, IShspInstance instance, Opts opts)
→ Future<IShspInstance>
-
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
destroy()
→ void
-
Destroys the singleton instance