get method

MessageCallbackFunction? get(
  1. String key
)

Get a callback invoker for a specific remote endpoint Returns a function that invokes the registered callback for this key

Implementation

MessageCallbackFunction? get(String key) {
  return _handlers[key]?.call;
}