RawShspSocket class

Hoping that in a future RawDatagramSocket (or similar) will become a real class (AS NOW THERE IS NOT OTHER OPTION BECAUSE RawDatagramSocket IS AN ABSTRACT CLASS)

Implemented types
Implementers

Constructors

RawShspSocket(RawDatagramSocket socket)

Properties

address → InternetAddress
The address used by this socket.
no setteroverride
broadcastEnabled ↔ bool
Whether IPv4 broadcast is enabled.
getter/setter pairoverride
first → Future<RawSocketEvent>
The first element of this stream.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
isBroadcast → bool
Whether this stream is a broadcast stream.
no setteroverride
isEmpty → Future<bool>
Whether this stream contains any elements.
no setteroverride
last → Future<RawSocketEvent>
The last element of this stream.
no setteroverride
length → Future<int>
The number of elements in this stream.
no setteroverride
multicastHops ↔ int
The maximum network hops for multicast packages originating from this socket.
getter/setter pairoverride
multicastInterface ↔ NetworkInterface?
The network interface used for outgoing multicast packages.
getter/setter pairoverride
multicastLoopback ↔ bool
Whether multicast traffic is looped back to the host.
getter/setter pairoverride
port → int
The port used by this socket.
no setteroverride
readEventsEnabled ↔ bool
Whether the RawDatagramSocket should listen for RawSocketEvent.read events.
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → Future<RawSocketEvent>
The single element of this stream.
no setteroverride
socket → RawDatagramSocket
final
writeEventsEnabled ↔ bool
Whether the RawDatagramSocket should listen for RawSocketEvent.write events.
getter/setter pairoverride

Methods

any(bool test(RawSocketEvent)) → Future<bool>
Checks whether test accepts any element provided by this stream.
override
asBroadcastStream({void onListen(StreamSubscription<RawSocketEvent>)?, void onCancel(StreamSubscription<RawSocketEvent>)?}) → Stream<RawSocketEvent>
Returns a multi-subscription stream that produces the same events as this.
override
asyncExpand<E>(Stream<E>? convert(RawSocketEvent)) → Stream<E>
Transforms each element into a sequence of asynchronous events.
override
asyncMap<E>(FutureOr<E> convert(RawSocketEvent)) → Stream<E>
Creates a new stream with each data event of this stream asynchronously mapped to a new event.
override
cast<R>() → Stream<R>
Adapt this stream to be a Stream<R>.
override
close() → void
Closes the datagram socket.
override
contains(Object? needle) → Future<bool>
Returns whether needle occurs in the elements provided by this stream.
override
distinct([bool equals(RawSocketEvent, RawSocketEvent)?]) → Stream<RawSocketEvent>
Skips data events if they are equal to the previous data event.
override
drain<E>([E? futureValue]) → Future<E>
Discards all data on this stream, but signals when it is done or an error occurred.
override
elementAt(int index) → Future<RawSocketEvent>
Returns the value of the indexth data event of this stream.
override
every(bool test(RawSocketEvent)) → Future<bool>
Checks whether test accepts all elements provided by this stream.
override
expand<S>(Iterable<S> convert(RawSocketEvent)) → Stream<S>
Transforms each element of this stream into a sequence of elements.
override
firstWhere(bool test(RawSocketEvent), {RawSocketEvent orElse()?}) → Future<RawSocketEvent>
Finds the first element of this stream matching test.
override
fold<T>(T initialValue, T combine(T, RawSocketEvent)) → Future<T>
Combines a sequence of values by repeatedly applying combine.
override
forEach(void action(RawSocketEvent)) → Future<void>
Executes action on each element of this stream.
override
getRawOption(RawSocketOption option) → Uint8List
Reads low level information about the RawSocket.
override
handleError(Function onError, {bool test(dynamic)?}) → Stream<RawSocketEvent>
Creates a wrapper Stream that intercepts some errors from this stream.
override
join([String separator = '']) → Future<String>
Combines the string representation of elements into a single string.
override
joinMulticast(InternetAddress group, [NetworkInterface? interface]) → void
Joins a multicast group.
override
lastWhere(bool test(RawSocketEvent), {RawSocketEvent orElse()?}) → Future<RawSocketEvent>
Finds the last element in this stream matching test.
override
leaveMulticast(InternetAddress group, [NetworkInterface? interface]) → void
Leaves a multicast group.
override
listen(void onData(RawSocketEvent event)?, {Function? onError, void onDone()?, bool? cancelOnError}) → StreamSubscription<RawSocketEvent>
Adds a subscription to this stream.
override
map<S>(S convert(RawSocketEvent)) → Stream<S>
Transforms each element of this stream into a new stream event.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pipe(StreamConsumer<RawSocketEvent> streamConsumer) → Future<void>
Pipes the events of this stream into streamConsumer.
override
receive() → Datagram?
Receives a datagram.
override
reduce(RawSocketEvent combine(RawSocketEvent, RawSocketEvent)) → Future<RawSocketEvent>
Combines a sequence of values by repeatedly applying combine.
override
send(List<int> buffer, InternetAddress address, int port) → int
Asynchronously sends a datagram.
override
setRawOption(RawSocketOption option) → void
Customizes the RawSocket.
override
singleWhere(bool test(RawSocketEvent), {RawSocketEvent orElse()?}) → Future<RawSocketEvent>
Finds the single element in this stream matching test.
override
skip(int count) → Stream<RawSocketEvent>
Skips the first count data events from this stream.
override
skipWhile(bool test(RawSocketEvent)) → Stream<RawSocketEvent>
Skip data events from this stream while they are matched by test.
override
take(int count) → Stream<RawSocketEvent>
Provides at most the first count data events of this stream.
override
takeWhile(bool test(RawSocketEvent)) → Stream<RawSocketEvent>
Forwards data events while test is successful.
override
timeout(Duration timeLimit, {void onTimeout(EventSink<RawSocketEvent>)?}) → Stream<RawSocketEvent>
Creates a new stream with the same events as this stream.
override
toList() → Future<List<RawSocketEvent>>
Collects all elements of this stream in a List.
override
toSet() → Future<Set<RawSocketEvent>>
Collects the data of this stream in a Set.
override
toString() → String
A string representation of this object.
inherited
transform<S>(StreamTransformer<RawSocketEvent, S> streamTransformer) → Stream<S>
Applies streamTransformer to this stream.
override
where(bool test(RawSocketEvent)) → Stream<RawSocketEvent>
Creates a new stream from this stream that discards some elements.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited