multicastHops property

  1. @override
int get multicastHops
override

The maximum network hops for multicast packages originating from this socket.

For IPv4 this is referred to as TTL (time to live).

By default this value is 1 causing multicast traffic to stay on the local network.

Implementation

@override
int get multicastHops => socket.multicastHops;
  1. @override
set multicastHops (int value)
override

The maximum network hops for multicast packages originating from this socket.

For IPv4 this is referred to as TTL (time to live).

By default this value is 1 causing multicast traffic to stay on the local network.

Implementation

@override
set multicastHops(int value) => socket.multicastHops = value;