ShspSocketInfoSingleton class

Constructors

ShspSocketInfoSingleton()
Factory constructor that returns or creates the singleton instance
factory

Properties

address String
final
hashCode int
The hash code for this object.
no setterinherited
port int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

destroy() → void
Destroys the singleton instance