ShspInstanceFactory class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
{required PeerInfo remotePeer, required IShspSocket socket, int keepAliveSeconds = 30}) → ShspInstance -
createFromConfig(
ShspInstanceInput config) → ShspInstance -
Create a
ShspInstancefrom aShspInstanceConfigobject. -
createFromSocket(
{required PeerInfo remotePeer, required RawDatagramSocket rawSocket, int keepAliveSeconds = 30}) → ShspInstance - Create a ShspInstance from PeerInfo and a RawDatagramSocket, building dependencies.