single_hand_shake_protocol_monorepo library
Classes
- AddressUtility
- Utility functions for address formatting
- AddressUtilityFactory
-
CallbackMap<
T> - Generic callback map for managing callbacks by string keys Similar to TypeScript's CallbackMap
- CallbackMapFactory
- ConcatUtility
- Utility functions for concatenating data
- ConcatUtilityInput
- HandshakeIP
- HandshakeOwnership
- HandshakeTime
- KeepAliveTimer
- Custom timer for managing keep-alive messages with intelligent activity tracking
- KeepAliveTimerFactory
- KeepAliveTimerInput
- MessageCallbackMap
- A specialized callback map for handling messages from remote endpoints Supports both IPv4 and IPv6 addresses Key format:
- MessageCallbackMapFactory
- MessageCallbackMapSingleton
- RawShspSocket
- Hoping that in a future RawDatagramSocket (or similar) will become a real class (AS NOW THERE IS NOT OTHER OPTION BECAUSE RawDatagramSocket IS AN ABSTRACT CLASS)
- RawShspSocketInput
- ShspInput
- ShspInstance
- SHSP Instance: manages handshake, closure, keep-alive and data messages.
- ShspInstanceFactory
- ShspInstanceHandler
- ShspInstanceHandlerSingleton
- ShspInstanceInput
- ShspPeer
- SHSP Peer implementation
- ShspPeerFactory
- ShspPeerInput
- ShspSocket
- SHSP Socket implementation wrapping RawDatagramSocket
- ShspSocketFactory
- ShspSocketInfoSingleton
- ShspSocketInput
Constants
- closedPrefix → const int
- closingPrefix → const int
- dataPrefix → const int
- handshakePrefix → const int
- keepAlivePrefix → const int
Properties
Typedefs
-
Callback<
T> = void Function(T args) - Generic type for callbacks
-
CallbackOnMessage
= CallbackHandler<
MessageRecord, void> - InputFactoryHandshakeTime = ({int? handshakeDuration, int? handshakeTimeframe, int? whenLastHandshake})
- InputHandshakeIP = ({PeerInfo? localIPv4, PeerInfo? localIPv6, PeerInfo? publicIPv4, PeerInfo? publicIPv6})
- InputHandshakeOwnership = ({String signedNonce})
- InputHandshakeTime = ({DateTime endHandshakeTime, int handshakeDuration, int handshakeTimeframe, DateTime startHandshakeTime})