ConcatUtility class
Utility functions for concatenating data
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
bytesToString(
Uint8List bytes, {Encoding encoding = utf8}) → String - Convert a Uint8List to String
-
concatBytes(
List< Uint8List> arrays) → Uint8List - Concatenate multiple Uint8List (byte arrays)
-
concatIntLists(
List< List< lists) → List<int> >int> -
Concatenate multiple
List<int>(generic int lists) -
concatMixed(
List items) → Uint8List - Concatenate mixed types (strings and byte arrays) All strings are converted to bytes using UTF-8 encoding
-
concatStrings(
List< String> strings) → String - Concatenate multiple strings
-
stringToBytes(
String str, {Encoding encoding = utf8}) → Uint8List - Convert a String to Uint8List